Learn R Programming

featurefinder (version 1.1)

doAllFactors: doAllFactors

Description

Sample data based on dataset mpg in the ggplot2 package

Arguments

Format

A boolean to indicate whether to scan over all categorical factor partitions.

Author

Richard Davis richard.davis@cba.com.au

Examples

Run this code
data(doAllFactors)
head(doAllFactors)

Run the code above in your browser using DataLab