Learn R Programming

featurefinder (version 1.1)

expr: expr

Description

Sample data based on dataset mpg in the ggplot2 package

Arguments

Format

A string describing the formula defining a leaf node.

Author

Richard Davis richard.davis@cba.com.au

Examples

Run this code
data(expr)
head(expr)

Run the code above in your browser using DataLab