Learn R Programming

featurefinder (version 1.0)

getVarAv: getVarAv

Description

This function generates a residual tree on a subset of the data

Usage

getVarAv(dd, varAv, varString)

Arguments

dd

A dataframe

varAv

A string corresponding to the numeric field to be averaged within each leaf node

varString

A string

Value

An average of the numeric variable varString in the segment

Examples

Run this code
# NOT RUN {
require(featurefinder)
data(examples)
av=getVarAv(dat,"expected",pathterms)
# }

Run the code above in your browser using DataLab