Learn R Programming

featurefinder (version 1.1)

mainfaclevels: mainfaclevels

Description

Sample data based on dataset mpg in the ggplot2 package

Arguments

Format

Levels of the main or current factor being scanned.

Author

Richard Davis richard.davis@cba.com.au

Examples

Run this code
data(mainfaclevels)
head(mainfaclevels)

Run the code above in your browser using DataLab