Learn R Programming

featurefinder (version 1.1)

maxFactorLevels: maxFactorLevels

Description

Sample data based on dataset mpg in the ggplot2 package

Arguments

Format

Maximum allowable number of factor levels before the variable is converted to numeric.

Author

Richard Davis richard.davis@cba.com.au

Examples

Run this code
data(maxFactorLevels)
head(maxFactorLevels)

Run the code above in your browser using DataLab