Learn R Programming

featurefinder (version 1.1)

runname: runname

Description

Sample data based on dataset mpg in the ggplot2 package

Arguments

Format

A string corresponding to the name of the variable being modelled

Author

Richard Davis richard.davis@cba.com.au

Examples

Run this code
data(runname)
head(runname)

Run the code above in your browser using DataLab