powered by
Sample data based on dataset mpg in the ggplot2 package
A boolean to indicate whether to scan over all categorical factor partitions.
Richard Davis richard.davis@cba.com.au
data(doAllFactors) head(doAllFactors)
Run the code above in your browser using DataLab