powered by
Sample data based on dataset mpg in the ggplot2 package
A string describing the formula defining a leaf node.
Richard Davis richard.davis@cba.com.au
data(expr) head(expr)
Run the code above in your browser using DataLab