powered by
This function generates a residual tree on a subset of the data
getVarAv(dd, varAv, varString)
A dataframe
A string corresponding to the numeric field to be averaged within each leaf node
A string
An average of the numeric variable varString in the segment
# NOT RUN { require(featurefinder) data(examples) av=getVarAv(dat,"expected",pathterms) # }
Run the code above in your browser using DataLab