powered by
Sample data based on dataset mpg in the ggplot2 package
Levels of the main or current factor being scanned.
Richard Davis richard.davis@cba.com.au
data(mainfaclevels) head(mainfaclevels)
Run the code above in your browser using DataLab