powered by
Sample data based on dataset mpg in the ggplot2 package
Maximum allowable number of factor levels before the variable is converted to numeric.
Richard Davis richard.davis@cba.com.au
data(maxFactorLevels) head(maxFactorLevels)
Run the code above in your browser using DataLab