powered by
Sample data based on dataset mpg in the ggplot2 package
A string corresponding to the name of the variable being modelled
Richard Davis richard.davis@cba.com.au
data(runname) head(runname)
Run the code above in your browser using DataLab